#[non_exhaustive]pub struct AssociateAdminAccountInput {
pub admin_account: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_account: Option<String>The Amazon Web Services account ID to associate with Firewall Manager as the Firewall Manager default administrator account. This account must be a member account of the organization in Organizations whose resources you want to protect. For more information about Organizations, see Managing the Amazon Web Services Accounts in Your Organization.
Implementations
Sourceimpl AssociateAdminAccountInput
impl AssociateAdminAccountInput
Sourcepub fn admin_account(&self) -> Option<&str>
pub fn admin_account(&self) -> Option<&str>
The Amazon Web Services account ID to associate with Firewall Manager as the Firewall Manager default administrator account. This account must be a member account of the organization in Organizations whose resources you want to protect. For more information about Organizations, see Managing the Amazon Web Services Accounts in Your Organization.
Sourceimpl AssociateAdminAccountInput
impl AssociateAdminAccountInput
Sourcepub fn builder() -> AssociateAdminAccountInputBuilder
pub fn builder() -> AssociateAdminAccountInputBuilder
Creates a new builder-style object to manufacture AssociateAdminAccountInput.