#[non_exhaustive]pub struct Ec2CopyRouteTableAction {
pub description: Option<String>,
pub vpc_id: Option<ActionTarget>,
pub route_table_id: Option<ActionTarget>,
}Expand description
An action that copies the EC2 route table for use in remediation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>A description of the copied EC2 route table that is associated with the remediation action.
vpc_id: Option<ActionTarget>The VPC ID of the copied EC2 route table that is associated with the remediation action.
route_table_id: Option<ActionTarget>The ID of the copied EC2 route table that is associated with the remediation action.
Implementations
Sourceimpl Ec2CopyRouteTableAction
impl Ec2CopyRouteTableAction
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the copied EC2 route table that is associated with the remediation action.
Sourcepub fn vpc_id(&self) -> Option<&ActionTarget>
pub fn vpc_id(&self) -> Option<&ActionTarget>
The VPC ID of the copied EC2 route table that is associated with the remediation action.
Sourcepub fn route_table_id(&self) -> Option<&ActionTarget>
pub fn route_table_id(&self) -> Option<&ActionTarget>
The ID of the copied EC2 route table that is associated with the remediation action.
Sourceimpl Ec2CopyRouteTableAction
impl Ec2CopyRouteTableAction
Sourcepub fn builder() -> Ec2CopyRouteTableActionBuilder
pub fn builder() -> Ec2CopyRouteTableActionBuilder
Creates a new builder-style object to manufacture Ec2CopyRouteTableAction.