#[non_exhaustive]pub struct Ec2CreateRouteAction {
pub description: Option<String>,
pub destination_cidr_block: Option<String>,
pub destination_prefix_list_id: Option<String>,
pub destination_ipv6_cidr_block: Option<String>,
pub vpc_endpoint_id: Option<ActionTarget>,
pub gateway_id: Option<ActionTarget>,
pub route_table_id: Option<ActionTarget>,
}Expand description
Information about the CreateRoute action in Amazon EC2.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>A description of CreateRoute action in Amazon EC2.
destination_cidr_block: Option<String>Information about the IPv4 CIDR address block used for the destination match.
destination_prefix_list_id: Option<String>Information about the ID of a prefix list used for the destination match.
destination_ipv6_cidr_block: Option<String>Information about the IPv6 CIDR block destination.
vpc_endpoint_id: Option<ActionTarget>Information about the ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
gateway_id: Option<ActionTarget>Information about the ID of an internet gateway or virtual private gateway attached to your VPC.
route_table_id: Option<ActionTarget>Information about the ID of the route table for the route.
Implementations
Sourceimpl Ec2CreateRouteAction
impl Ec2CreateRouteAction
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of CreateRoute action in Amazon EC2.
Sourcepub fn destination_cidr_block(&self) -> Option<&str>
pub fn destination_cidr_block(&self) -> Option<&str>
Information about the IPv4 CIDR address block used for the destination match.
Sourcepub fn destination_prefix_list_id(&self) -> Option<&str>
pub fn destination_prefix_list_id(&self) -> Option<&str>
Information about the ID of a prefix list used for the destination match.
Sourcepub fn destination_ipv6_cidr_block(&self) -> Option<&str>
pub fn destination_ipv6_cidr_block(&self) -> Option<&str>
Information about the IPv6 CIDR block destination.
Sourcepub fn vpc_endpoint_id(&self) -> Option<&ActionTarget>
pub fn vpc_endpoint_id(&self) -> Option<&ActionTarget>
Information about the ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
Sourcepub fn gateway_id(&self) -> Option<&ActionTarget>
pub fn gateway_id(&self) -> Option<&ActionTarget>
Information about the ID of an internet gateway or virtual private gateway attached to your VPC.
Sourcepub fn route_table_id(&self) -> Option<&ActionTarget>
pub fn route_table_id(&self) -> Option<&ActionTarget>
Information about the ID of the route table for the route.
Sourceimpl Ec2CreateRouteAction
impl Ec2CreateRouteAction
Sourcepub fn builder() -> Ec2CreateRouteActionBuilder
pub fn builder() -> Ec2CreateRouteActionBuilder
Creates a new builder-style object to manufacture Ec2CreateRouteAction.