#[non_exhaustive]pub struct EntryDescription {
pub entry_detail: Option<NetworkAclEntry>,
pub entry_rule_number: i32,
pub entry_type: Option<EntryType>,
}Expand description
Describes a single rule in a network ACL.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry_detail: Option<NetworkAclEntry>Describes a rule in a network ACL.
Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the network ACL, Amazon Web Services processes the entries in the network ACL according to the rule numbers, in ascending order.
When you manage an individual network ACL, you explicitly specify the rule numbers. When you specify the network ACL rules in a Firewall Manager policy, you provide the rules to run first, in the order that you want them to run, and the rules to run last, in the order that you want them to run. Firewall Manager assigns the rule numbers for you when you save the network ACL policy specification.
entry_rule_number: i32The rule number for the entry. ACL entries are processed in ascending order by rule number. In a Firewall Manager network ACL policy, Firewall Manager assigns rule numbers.
entry_type: Option<EntryType>Specifies whether the entry is managed by Firewall Manager or by a user, and, for Firewall Manager-managed entries, specifies whether the entry is among those that run first in the network ACL or those that run last.
Implementations
Sourceimpl EntryDescription
impl EntryDescription
Sourcepub fn entry_detail(&self) -> Option<&NetworkAclEntry>
pub fn entry_detail(&self) -> Option<&NetworkAclEntry>
Describes a rule in a network ACL.
Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the network ACL, Amazon Web Services processes the entries in the network ACL according to the rule numbers, in ascending order.
When you manage an individual network ACL, you explicitly specify the rule numbers. When you specify the network ACL rules in a Firewall Manager policy, you provide the rules to run first, in the order that you want them to run, and the rules to run last, in the order that you want them to run. Firewall Manager assigns the rule numbers for you when you save the network ACL policy specification.
Sourcepub fn entry_rule_number(&self) -> i32
pub fn entry_rule_number(&self) -> i32
The rule number for the entry. ACL entries are processed in ascending order by rule number. In a Firewall Manager network ACL policy, Firewall Manager assigns rule numbers.
Sourcepub fn entry_type(&self) -> Option<&EntryType>
pub fn entry_type(&self) -> Option<&EntryType>
Specifies whether the entry is managed by Firewall Manager or by a user, and, for Firewall Manager-managed entries, specifies whether the entry is among those that run first in the network ACL or those that run last.
Sourceimpl EntryDescription
impl EntryDescription
Sourcepub fn builder() -> EntryDescriptionBuilder
pub fn builder() -> EntryDescriptionBuilder
Creates a new builder-style object to manufacture EntryDescription.