NetworkFirewallPolicyModifiedViolation

Struct NetworkFirewallPolicyModifiedViolation 

#[non_exhaustive]
pub struct NetworkFirewallPolicyModifiedViolation { pub violation_target: Option<String>, pub current_policy_description: Option<NetworkFirewallPolicyDescription>, pub expected_policy_description: Option<NetworkFirewallPolicyDescription>, }
Violation detail for Network Firewall for a firewall policy that has a different NetworkFirewallPolicyDescription than is required by the Firewall Manager policy.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
violation_target: Option<String>

The ID of the Network Firewall or VPC resource that's in violation.

current_policy_description: Option<NetworkFirewallPolicyDescription>

The policy that's currently in use in the individual account.

expected_policy_description: Option<NetworkFirewallPolicyDescription>

The policy that should be in use in the individual account in order to be compliant.

Implementations

Source

impl NetworkFirewallPolicyModifiedViolation

pub fn violation_target(&self) -> Option<&str>

The ID of the Network Firewall or VPC resource that's in violation.

pub fn current_policy_description( &self, ) -> Option<&NetworkFirewallPolicyDescription>

The policy that's currently in use in the individual account.

pub fn expected_policy_description( &self, ) -> Option<&NetworkFirewallPolicyDescription>

The policy that should be in use in the individual account in order to be compliant.

Source

impl NetworkFirewallPolicyModifiedViolation

pub fn builder() -> NetworkFirewallPolicyModifiedViolationBuilder

Creates a new builder-style object to manufacture NetworkFirewallPolicyModifiedViolation.