#[non_exhaustive]pub struct StatelessRuleGroup {
pub rule_group_name: Option<String>,
pub resource_id: Option<String>,
pub priority: Option<i32>,
}Expand description
Network Firewall stateless rule group, used in a NetworkFirewallPolicyDescription.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_group_name: Option<String>The name of the rule group.
resource_id: Option<String>The resource ID of the rule group.
priority: Option<i32>The priority of the rule group. Network Firewall evaluates the stateless rule groups in a firewall policy starting from the lowest priority setting.
Implementations
Sourceimpl StatelessRuleGroup
impl StatelessRuleGroup
Sourcepub fn rule_group_name(&self) -> Option<&str>
pub fn rule_group_name(&self) -> Option<&str>
The name of the rule group.
Sourcepub fn resource_id(&self) -> Option<&str>
pub fn resource_id(&self) -> Option<&str>
The resource ID of the rule group.
Sourceimpl StatelessRuleGroup
impl StatelessRuleGroup
Sourcepub fn builder() -> StatelessRuleGroupBuilder
pub fn builder() -> StatelessRuleGroupBuilder
Creates a new builder-style object to manufacture StatelessRuleGroup.