#[non_exhaustive]pub struct NetworkFirewallInvalidRouteConfigurationViolation {Show 16 fields
pub affected_subnets: Option<Vec<String>>,
pub route_table_id: Option<String>,
pub is_route_table_used_in_different_az: bool,
pub violating_route: Option<Route>,
pub current_firewall_subnet_route_table: Option<String>,
pub expected_firewall_endpoint: Option<String>,
pub actual_firewall_endpoint: Option<String>,
pub expected_firewall_subnet_id: Option<String>,
pub actual_firewall_subnet_id: Option<String>,
pub expected_firewall_subnet_routes: Option<Vec<ExpectedRoute>>,
pub actual_firewall_subnet_routes: Option<Vec<Route>>,
pub internet_gateway_id: Option<String>,
pub current_internet_gateway_route_table: Option<String>,
pub expected_internet_gateway_routes: Option<Vec<ExpectedRoute>>,
pub actual_internet_gateway_routes: Option<Vec<Route>>,
pub vpc_id: Option<String>,
}Expand description
Violation detail for the improperly configured subnet route. It's possible there is a missing route table route, or a configuration that causes traffic to cross an Availability Zone boundary.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.affected_subnets: Option<Vec<String>>The subnets that are affected.
route_table_id: Option<String>The route table ID.
is_route_table_used_in_different_az: boolInformation about whether the route table is used in another Availability Zone.
violating_route: Option<Route>The route that's in violation.
current_firewall_subnet_route_table: Option<String>The subnet route table for the current firewall.
expected_firewall_endpoint: Option<String>The firewall endpoint that's expected.
actual_firewall_endpoint: Option<String>The actual firewall endpoint.
expected_firewall_subnet_id: Option<String>The expected subnet ID for the firewall.
actual_firewall_subnet_id: Option<String>The actual subnet ID for the firewall.
expected_firewall_subnet_routes: Option<Vec<ExpectedRoute>>The firewall subnet routes that are expected.
actual_firewall_subnet_routes: Option<Vec<Route>>The actual firewall subnet routes that are expected.
internet_gateway_id: Option<String>The internet gateway ID.
current_internet_gateway_route_table: Option<String>The route table for the current internet gateway.
expected_internet_gateway_routes: Option<Vec<ExpectedRoute>>The expected routes for the internet gateway.
actual_internet_gateway_routes: Option<Vec<Route>>The actual internet gateway routes.
vpc_id: Option<String>Information about the VPC ID.
Implementations
Sourceimpl NetworkFirewallInvalidRouteConfigurationViolation
impl NetworkFirewallInvalidRouteConfigurationViolation
Sourcepub fn affected_subnets(&self) -> &[String]
pub fn affected_subnets(&self) -> &[String]
The subnets that are affected.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .affected_subnets.is_none().
Sourcepub fn route_table_id(&self) -> Option<&str>
pub fn route_table_id(&self) -> Option<&str>
The route table ID.
Sourcepub fn is_route_table_used_in_different_az(&self) -> bool
pub fn is_route_table_used_in_different_az(&self) -> bool
Information about whether the route table is used in another Availability Zone.
Sourcepub fn violating_route(&self) -> Option<&Route>
pub fn violating_route(&self) -> Option<&Route>
The route that's in violation.
Sourcepub fn current_firewall_subnet_route_table(&self) -> Option<&str>
pub fn current_firewall_subnet_route_table(&self) -> Option<&str>
The subnet route table for the current firewall.
Sourcepub fn expected_firewall_endpoint(&self) -> Option<&str>
pub fn expected_firewall_endpoint(&self) -> Option<&str>
The firewall endpoint that's expected.
Sourcepub fn actual_firewall_endpoint(&self) -> Option<&str>
pub fn actual_firewall_endpoint(&self) -> Option<&str>
The actual firewall endpoint.
Sourcepub fn expected_firewall_subnet_id(&self) -> Option<&str>
pub fn expected_firewall_subnet_id(&self) -> Option<&str>
The expected subnet ID for the firewall.
Sourcepub fn actual_firewall_subnet_id(&self) -> Option<&str>
pub fn actual_firewall_subnet_id(&self) -> Option<&str>
The actual subnet ID for the firewall.
Sourcepub fn expected_firewall_subnet_routes(&self) -> &[ExpectedRoute]
pub fn expected_firewall_subnet_routes(&self) -> &[ExpectedRoute]
The firewall subnet routes that are expected.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .expected_firewall_subnet_routes.is_none().
Sourcepub fn actual_firewall_subnet_routes(&self) -> &[Route]
pub fn actual_firewall_subnet_routes(&self) -> &[Route]
The actual firewall subnet routes that are expected.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actual_firewall_subnet_routes.is_none().
Sourcepub fn internet_gateway_id(&self) -> Option<&str>
pub fn internet_gateway_id(&self) -> Option<&str>
The internet gateway ID.
Sourcepub fn current_internet_gateway_route_table(&self) -> Option<&str>
pub fn current_internet_gateway_route_table(&self) -> Option<&str>
The route table for the current internet gateway.
Sourcepub fn expected_internet_gateway_routes(&self) -> &[ExpectedRoute]
pub fn expected_internet_gateway_routes(&self) -> &[ExpectedRoute]
The expected routes for the internet gateway.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .expected_internet_gateway_routes.is_none().
Sourcepub fn actual_internet_gateway_routes(&self) -> &[Route]
pub fn actual_internet_gateway_routes(&self) -> &[Route]
The actual internet gateway routes.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .actual_internet_gateway_routes.is_none().
Sourceimpl NetworkFirewallInvalidRouteConfigurationViolation
impl NetworkFirewallInvalidRouteConfigurationViolation
Sourcepub fn builder() -> NetworkFirewallInvalidRouteConfigurationViolationBuilder
pub fn builder() -> NetworkFirewallInvalidRouteConfigurationViolationBuilder
Creates a new builder-style object to manufacture NetworkFirewallInvalidRouteConfigurationViolation.