#[non_exhaustive]pub struct NetworkFirewallPolicyModifiedViolation {
pub violation_target: Option<String>,
pub current_policy_description: Option<NetworkFirewallPolicyDescription>,
pub expected_policy_description: Option<NetworkFirewallPolicyDescription>,
}Expand description
Violation detail for Network Firewall for a firewall policy that has a different NetworkFirewallPolicyDescription than is required by the Firewall Manager policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.violation_target: Option<String>The ID of the Network Firewall or VPC resource that's in violation.
current_policy_description: Option<NetworkFirewallPolicyDescription>The policy that's currently in use in the individual account.
expected_policy_description: Option<NetworkFirewallPolicyDescription>The policy that should be in use in the individual account in order to be compliant.
Implementations
Sourceimpl NetworkFirewallPolicyModifiedViolation
impl NetworkFirewallPolicyModifiedViolation
Sourcepub fn violation_target(&self) -> Option<&str>
pub fn violation_target(&self) -> Option<&str>
The ID of the Network Firewall or VPC resource that's in violation.
Sourcepub fn current_policy_description(
&self,
) -> Option<&NetworkFirewallPolicyDescription>
pub fn current_policy_description( &self, ) -> Option<&NetworkFirewallPolicyDescription>
The policy that's currently in use in the individual account.
Sourcepub fn expected_policy_description(
&self,
) -> Option<&NetworkFirewallPolicyDescription>
pub fn expected_policy_description( &self, ) -> Option<&NetworkFirewallPolicyDescription>
The policy that should be in use in the individual account in order to be compliant.
Sourceimpl NetworkFirewallPolicyModifiedViolation
impl NetworkFirewallPolicyModifiedViolation
Sourcepub fn builder() -> NetworkFirewallPolicyModifiedViolationBuilder
pub fn builder() -> NetworkFirewallPolicyModifiedViolationBuilder
Creates a new builder-style object to manufacture NetworkFirewallPolicyModifiedViolation.