#[non_exhaustive]pub struct StatefulEngineOptions {
pub rule_order: Option<RuleOrder>,
pub stream_exception_policy: Option<StreamExceptionPolicy>,
}Expand description
Configuration settings for the handling of the stateful rule groups in a Network Firewall firewall policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_order: Option<RuleOrder>Indicates how to manage the order of stateful rule evaluation for the policy. Stateful rules are provided to the rule engine as Suricata compatible strings, and Suricata evaluates them based on certain settings. For more information, see Evaluation order for stateful rules in the Network Firewall Developer Guide.
Default: DEFAULT_ACTION_ORDER
stream_exception_policy: Option<StreamExceptionPolicy>Indicates how Network Firewall should handle traffic when a network connection breaks midstream.
-
DROP- Fail closed and drop all subsequent traffic going to the firewall. -
CONTINUE- Continue to apply rules to subsequent traffic without context from traffic before the break. This impacts the behavior of rules that depend on context. For example, with a stateful rule that drops HTTP traffic, Network Firewall won't match subsequent traffic because the it won't have the context from session initialization, which defines the application layer protocol as HTTP. However, a TCP-layer rule using aflow:statelessrule would still match, and so would theaws:drop_strictdefault action. -
REJECT- Fail closed and drop all subsequent traffic going to the firewall. With this option, Network Firewall also sends a TCP reject packet back to the client so the client can immediately establish a new session. With the new session, Network Firewall will have context and will apply rules appropriately.For applications that are reliant on long-lived TCP connections that trigger Gateway Load Balancer idle timeouts, this is the recommended setting.
-
FMS_IGNORE- Firewall Manager doesn't monitor or modify the Network Firewall stream exception policy settings.
For more information, see Stream exception policy in your firewall policy in the Network Firewall Developer Guide.
Default: FMS_IGNORE
Implementations
Sourceimpl StatefulEngineOptions
impl StatefulEngineOptions
Sourcepub fn rule_order(&self) -> Option<&RuleOrder>
pub fn rule_order(&self) -> Option<&RuleOrder>
Indicates how to manage the order of stateful rule evaluation for the policy. Stateful rules are provided to the rule engine as Suricata compatible strings, and Suricata evaluates them based on certain settings. For more information, see Evaluation order for stateful rules in the Network Firewall Developer Guide.
Default: DEFAULT_ACTION_ORDER
Sourcepub fn stream_exception_policy(&self) -> Option<&StreamExceptionPolicy>
pub fn stream_exception_policy(&self) -> Option<&StreamExceptionPolicy>
Indicates how Network Firewall should handle traffic when a network connection breaks midstream.
-
DROP- Fail closed and drop all subsequent traffic going to the firewall. -
CONTINUE- Continue to apply rules to subsequent traffic without context from traffic before the break. This impacts the behavior of rules that depend on context. For example, with a stateful rule that drops HTTP traffic, Network Firewall won't match subsequent traffic because the it won't have the context from session initialization, which defines the application layer protocol as HTTP. However, a TCP-layer rule using aflow:statelessrule would still match, and so would theaws:drop_strictdefault action. -
REJECT- Fail closed and drop all subsequent traffic going to the firewall. With this option, Network Firewall also sends a TCP reject packet back to the client so the client can immediately establish a new session. With the new session, Network Firewall will have context and will apply rules appropriately.For applications that are reliant on long-lived TCP connections that trigger Gateway Load Balancer idle timeouts, this is the recommended setting.
-
FMS_IGNORE- Firewall Manager doesn't monitor or modify the Network Firewall stream exception policy settings.
For more information, see Stream exception policy in your firewall policy in the Network Firewall Developer Guide.
Default: FMS_IGNORE
Sourceimpl StatefulEngineOptions
impl StatefulEngineOptions
Sourcepub fn builder() -> StatefulEngineOptionsBuilder
pub fn builder() -> StatefulEngineOptionsBuilder
Creates a new builder-style object to manufacture StatefulEngineOptions.